==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/sound/translations/sound_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Klang</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Use sounds</source>
        <translation>Benutze Klänge</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Klang-Thema</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Pfad zu den Klängen</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Testklang wird abgespielt</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Spiele einen Klang ab</translation>
    </message>
</context>
<context>
    <name>SoundActions</name>
    <message>
        <source>Play Sounds</source>
        <translation>Spiele Klänge ab</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Eigene</translation>
    </message>
</context>
</TS>

==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/sound/translations/sound_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Klang</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Klang-Thema</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Pfad zu den Klängen</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Testklang wird abgespielt</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Spiele einen Klang ab</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Eigene</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
